@@ -24,7 +24,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: postgresql_stubs.c,v 1.11 2005/03/22 18:42:17 mottl Exp $ */
+/* $Id: postgresql_stubs.c,v 1.12 2005/05/31 16:00:47 mottl Exp $ */
 
 #include <string.h>
 
@@ -105,8 +105,7 @@ static value none = Val_int(0);
 static value make_some(value v)
 {
   CAMLparam1(v);
-  CAMLlocal1(res);
-  res = alloc_small(1, 0);
+  value res = alloc_small(1, 0);
   Field(res, 0) = v;
   CAMLreturn(res);
 }
@@ -115,7 +114,7 @@ static value make_some(value v)
 static value *exc_Oid = NULL;  /* Exception [Oid] */
 static value *exc_InternalError = NULL;  /* Exception [InternalError] */
 
-CAMLprim value PQocaml_init()
+CAMLprim value PQocaml_init(value unit)
 {
   register_global_root(&empty_string);
   empty_string = alloc_string(0);
@@ -256,7 +255,7 @@ CAMLprim value PQreset_stub(value vconn)
   CAMLreturn(Val_unit);
 }
 
-CAMLprim value PQconndefaults_stub()
+CAMLprim value PQconndefaults_stub(value unit)
 {
   CAMLparam0();
   CAMLlocal1(res);
@@ -499,11 +498,12 @@ CAMLprim value PQnotifies_stub(value vconn)
   PGnotify *noti = PQnotifies(get_conn(vconn));
 
   if (noti) {
-    CAMLlocal1(couple);
+    CAMLlocal1(str);
+    value couple;
+    str = make_string(noti->relname);
     couple = alloc_small(2, 0);
-    Field(couple, 0) = none;
+    Field(couple, 0) = str;
     Field(couple, 1) = Val_int(noti->be_pid);
-    modify(&Field(couple, 0), make_string(noti->relname));
     CAMLreturn(make_some(couple));
   }
   else CAMLreturn(none);
